@@ -8,11 +8,12 @@ import unittest
 import warnings
 
 from unittest2 import result, util
-from unittest2.compatibility import *
 
 try:
     from functools import wraps
 except ImportError:
+    # only needed for Python 2.4
+    import unittest2.compatibility
     def wraps(_):
         def _wraps(func):
             return func
